# Gibica

[![Release Status](https://img.shields.io/pypi/status/gibica.svg)](https://pypi.org/project/gibica)
[![Python Version](https://img.shields.io/pypi/pyversions/gibica.svg)](https://pypi.org/project/gibica)
[![Build Status](https://travis-ci.org/matthieugouel/gibica.svg?branch=master)](https://travis-ci.org/matthieugouel/gibica)
[![Coverage Status](https://coveralls.io/repos/github/matthieugouel/gibica/badge.svg?branch=master)](https://coveralls.io/github/matthieugouel/gibica?branch=master)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![Documentation Status](https://readthedocs.org/projects/gibica/badge/?version=latest)](http://gibica.readthedocs.io/en/latest/?badge=latest)
[![license](https://img.shields.io/github/license/matthieugouel/gibica.svg)](https://github.com/matthieugouel/gibica/blob/master/LICENSE)

> Interprète ? Interprète ? Cuillère ! -- King of Burgundy (Kaamelott).

## Installation

You can install the package using `pip` or `pipenv`. It requires Python 3.6.0+ to run.

```
pip install gibica
```

## Usage

After have installed the software, you can run it as a CLI program with your Gibica script file as an argument.

```
gibica script.gbc
```

For more information, you can display the help.

```
gibica --help
```

Feel free to checkout the documentation [here](http://gibica.readthedocs.io/en/latest/?badge=latest) !

## Contributing

See [CONTRIBUTING](CONTRIBUTING.md) for more information about how to contribute to this project.

## Credits

This project was initially born by the reading of the amazing series of articles [Let’s Build A Simple Interpreter](https://ruslanspivak.com/lsbasi-part1/) written by Ruslan Spivak.

I would also like to mention the project [CInterpreter](https://github.com/SKantar/CInterpreter) created by Slađan Kantar that inspired me during the development of this interpreter.
